@@ -136,6 +136,8 @@ pub trait RedisClientOwned: Sized {
 
   fn lpop<K: Into<RedisKey>>(self, key: K) -> Box<Future<Item=(Self, Option<RedisValue>), Error=RedisError>>;
 
+  fn memoryusage<K: Into<RedisKey>>(&self, key: K, samples: Option<i64>) -> Box<Future<Item=usize, Error=RedisError>>;
+
   fn sadd<K: Into<RedisKey>, V: Into<MultipleValues>>(self, key: K, values: V) -> Box<Future<Item=(Self, usize), Error=RedisError>>;
 
   fn srem<K: Into<RedisKey>, V: Into<MultipleValues>>(self, key: K, values: V) -> Box<Future<Item=(Self, usize), Error=RedisError>>;
@@ -590,6 +592,15 @@ impl RedisClientOwned for RedisClient {
     run_borrowed(self, |inner| commands::lpop(inner, key))
   }
 
+  /// Report the number of bytes that a key and its value require to be stored in RAM.
+  /// The reported usage is the total of memory allocations for data and administrative overheads that a key its value require.
+  /// For nested data types, the optional SAMPLES option can be provided, where count is the number of sampled nested values. By default, this option is set to 5. To sample the all of the nested values, use SAMPLES 0.
+  ///
+  /// <https://redis.io/commands/memory-usage>
+  fn memoryusage<K: Into<RedisKey>>(&self, key: K, samples: Option<i64>) -> Box<Future<Item=usize, Error=RedisError>> {
+    commands::memoryusage(&self.inner, key, samples)
+  }
+
   /// Add the specified value to the set stored at key. Values that are already a member of this set are ignored.
   /// If key does not exist, a new set is created before adding the specified value.
   /// An error is returned when the value stored at key is not a set.
