@@ -277,6 +277,7 @@ pub enum RedisCommandKind {
   LRem,
   LSet,
   LTrim,
+  MemoryUsage,
   Mget,
   Migrate,
   Monitor,
@@ -606,6 +607,7 @@ impl RedisCommandKind {
       RedisCommandKind::LRem                            => "LREM",
       RedisCommandKind::LSet                            => "LSET",
       RedisCommandKind::LTrim                           => "LTRIM",
+      RedisCommandKind::MemoryUsage                     => "MEMORY",
       RedisCommandKind::Mget                            => "MGET",
       RedisCommandKind::Migrate                         => "MIGRATE",
       RedisCommandKind::Monitor                         => "MONITOR",
@@ -804,6 +806,7 @@ impl RedisCommandKind {
       RedisCommandKind::LRem                            => "LREM",
       RedisCommandKind::LSet                            => "LSET",
       RedisCommandKind::LTrim                           => "LTRIM",
+      RedisCommandKind::MemoryUsage                     => "MEMORY",
       RedisCommandKind::Mget                            => "MGET",
       RedisCommandKind::Migrate                         => "MIGRATE",
       RedisCommandKind::Monitor                         => "MONITOR",
@@ -1004,6 +1007,22 @@ impl RedisCommandKind {
     Some(s.to_owned())
   }
 
+  pub fn is_memory_command(&self) -> bool {
+    match *self {
+      RedisCommandKind::MemoryUsage => true,
+      _ => false
+    }
+  }
+
+  pub fn memory_args(&self) -> Option<String> {
+    let s = match *self {
+      RedisCommandKind::MemoryUsage => "USAGE",
+      _ => return None
+    };
+
+    Some(s.to_owned())
+  }
+
   pub fn is_blocking(&self) -> bool {
     match *self {
       RedisCommandKind::BlPop(_)
